/* Define if symbols are prefixed with underscore */
#undef SYMBOL_UNDERSCORE

/* Tag to identify path to libgii.conf */
#define GIIPATHTAG	FIXME_DEFINE_THIS!

/* Name of LibGII master config file */
#define GIICONFFILE	FIXME_DEFINE_THIS!

/* Tag plus path to config dir */
#define GIICONFDIR	FIXME_DEFINE_THIS!

/* The length of the tag */
#define GIITAGLEN	FIXME_DEFINE_THIS!

/* Define if ggUSleep is a #define in ggi/system.h */
#undef GG_USLEEP_DEFINED

/* Undefine to disable run-time debugging */
#define DEBUG

/* Define if your libc has a __malloc_hook */
#undef HAVE_MALLOC_HOOK
